@@ -1,4 +1,4 @@
-__all__ = ('Contract', 'PaginationContract')
+__all__ = ('Contract',)
 
 from rest_framework import serializers
 
@@ -20,9 +20,3 @@ class Contract(serializers.Serializer):
 
     def create(self, validated_data):
         pass
-
-
-class PaginationContract(Contract):
-    previous = serializers.URLField(allow_null=True)
-    next = serializers.URLField(allow_null=True)
-    count = serializers.IntegerField()
