@@ -9,19 +9,21 @@ SERVICE = 'loans'
 
 
 class CommonLoan(Contract):
+    ISSUING = 'ISSUING'
     OPEN = "OPEN"  # Customer received money
     OVERDUE = "OVERDUE"
     STOP_INTEREST = "STOP_INTEREST"
     DEFAULT = "DEFAULT"
     CLOSED = "CLOSED"
     STATUS_CHOICES = {
+        (ISSUING, ISSUING),
         (OPEN, "Open"),
         (OVERDUE, "Overdue"),
         (STOP_INTEREST, "Stop interest"),
         (DEFAULT, "Default"),
         (CLOSED, "Closed")
     }
-    OPEN_STATUSES = (OPEN, OVERDUE, STOP_INTEREST, DEFAULT)
+    OPEN_STATUSES = (ISSUING, OPEN, OVERDUE, STOP_INTEREST, DEFAULT)
 
     id = serializers.IntegerField(min_value=1)
     created = serializers.DateTimeField()
