@@ -9,7 +9,6 @@ __all__ = ('PointRequestError', 'PointServerError', 'PointClientError', 'PointNo
            'ID', 'Contract',
            )
 
-import re
 from typing import OrderedDict, Union
 
 from django.contrib.auth import get_user_model
@@ -74,6 +73,7 @@ class PointRequestError(PointError):
 
 
 class PointServerError(PointRequestError):
+    default_detail = 'point_server_error'
     pass
 
 
@@ -165,15 +165,7 @@ class Point:
                     else:
                         raise PointClientError(self._client.url, response.status_code, response.json())
                 else:
-                    error = 'remaining connection slots are reserved for non-replication superuser connections'
-                    if re.search(rf'{error}', response.text):
-                        raise DatabasesPointServerError(self._client.url, response.status_code, error)
-                    elif re.search(r'OperationalError', response.text):
-                        raise DatabasesPointServerError(self._client.url, response.status_code,
-                                                        'Error related to database operation '
-                                                        '(disconnect, memory allocation).')
-                    else:
-                        raise PointServerError(self._client.url, response.status_code, response.text[:2048])
+                    raise PointServerError(self._client.url, response.status_code)
 
 
 class ObjectPoint(Point):
