@@ -18,7 +18,7 @@ class OrderScoringResponseContract(Contract):
 
 
 class OrderScoringReadContract(OrderScoringResponseContract):
-    pagination = PaginationContract()
+    pass
 
 
 class OrderScoringID(ID):
